@@ -10,7 +10,7 @@ use Types::Standard qw(Str);
 
 with 'Role::REST::Client';
 
-our $VERSION = '0.1.3';
+our $VERSION = '0.1.4';
 
 has api_url => (
     isa     => Str,
@@ -160,7 +160,7 @@ To setup the development environment and run the test using Carton.
 
 To enable Perl::Critic test cases, enable the flag.
 
-    $ TEST_CRITIC=1 carton exec -- prove -Ilib -lv t
+    $ AUTHOR_TESTING=1 carton exec -- prove -Ilib -lv t
 
 =head2 Minilla
 
@@ -172,6 +172,64 @@ To use Minilla instead. This will update the README.md file from the source.
     $ FAKE_RELEASE=1 minil release # testing
     $ minil release # actual
 
+=head1 METHODS
+
+=head2 BUILD
+
+Constructor of the object.
+
+    # Instantiate the class.
+    my $swapi = Webservice::Swapi->new;
+
+    # Set the API URL.
+    my $swapi = Webservice::Swapi->new(api_url => 'http://example.com/api/');
+
+=head2 get_object
+
+Get full details of a object or resource.
+
+    # Get the details of different available object using id.
+    my $object = $swapi->get_object('films', '1');
+
+    # Get the result in different format.
+    my $object_json = $swapi->get_object('films', '1', 'json');
+    my $object_wookie = $swapi->get_object('films', '1', 'wookiee');
+
+=head2 ping
+
+Check if the API service is responding to request.
+
+    my $server_status = $swapi->ping();
+
+=head2 resources
+
+List down all the available objects.
+
+    # Get all available resources (objects).
+    my $resources = $swapi->resources();
+
+    # Similarly but in different format.
+    my $resources_json = $swapi->resources('json');
+    my $resources_wookie = $swapi->resources('wookie');
+
+=head2 schema
+
+Show the data structure.
+
+    # Get the schema / structure of a resource or object.
+    my $schema = $swapi->schema('people');
+
+=head2 search
+
+Searching by keywords.
+
+    # Search a resource or object by keywords.
+    my $results = $swapi->search('people', 'solo');
+
+    # Or in different format.
+    my $results = $swapi->search('people', 'solo', 'json');
+    my $results = $swapi->search('people', 'solo', 'wookiee');
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is Copyright (c) 2017 by Kian Meng, Ang.
